@@ -1,7 +1,7 @@
-##' Convert a sequence of images to SWF file
+##' Convert a sequence of images to a SWF file
 ##'
 ##' Given the file names of a sequence of images, this function can
-##' convert them to a Flash file (.swf). Supported input formats are
+##' convert them into a Flash file (.swf). Supported input formats are
 ##' jpg/jpeg and png. The two formats are allowed to appear in the same
 ##' sequence.
 ##'
@@ -9,36 +9,49 @@
 ##' implement the conversion. If you want to create a Flash file
 ##' consisting of vector graphics, use \code{\link{svg2swf}()} instead.
 ##'
-##' @param filenames the file names of the images to be converted.
-##' @param outdir the output directory
-##' @param output the name of the output swf file.
-##' @param interval the time interval between animation frames.
+##' @param input the file names of the images to be converted
+##' @param output the name of the output SWF file
+##' @param bgColor background color of the output SWF file
+##' @param interval the time interval (in seconds) between animation frames
 ##' @return The path of the generated swf file if successful, or NULL is
 ##' returned.
 ##' @export
 ##' @author Yixuan Qiu <\email{yixuan.qiu@@cos.name}>
 ##' @examples if(capabilities("png")) {
+##'   olddir = setwd(tempdir())
 ##'   png("Rplot%03d.png")
 ##'   for(i in 1:9) plot(runif(20), ylim = c(0, 1))
 ##'   dev.off()
 ##'   output = image2swf(sprintf("Rplot%03d.png", 1:9))
 ##'   print(output)
+##'   setwd(olddir)
 ##' }
 ##'
-image2swf <- function(filenames, outdir = getwd(), output = "movie.swf",
+image2swf <- function(input, output = "./movie.swf", bgColor = "white",
 					  interval = 1)
 {
-	# The formats of files. 1 for png, 2 for jpg/jpeg, and 0 for others.
-	fmt = rep(0, length(filenames));
-	fmt[grep("\\.[Pp][Nn][Gg]$", filenames)] = 1;
-    fmt[grep("\\.[Jj][Pp][Ee]?[Gg]$", filenames)] = 2;
+    if(!inherits(input, "character")) 
+        stop("'input' must be a character vector naming the input images");
 	
-	oldwd = setwd(outdir);
-    .Call("image2swf", as.character(filenames), as.integer(fmt),
-	      as.character(output), as.numeric(interval),
+	outDir = dirname(output);
+	outFile = basename(output);
+	bg = col2rgb(bgColor, alpha = FALSE);
+	bg = as.integer(bg);
+
+	# The formats of files. 1 for png, 2 for jpg/jpeg, and 0 for others.
+	fmt = rep(0, length(input));
+	fmt[grep("\\.[Pp][Nn][Gg]$", input)] = 1;
+    fmt[grep("\\.[Jj][Pp][Ee]?[Gg]$", input)] = 2;
+	
+	oldwd = setwd(outDir);
+    .Call("image2swf", as.character(input), as.integer(fmt),
+	      as.character(output), bg, as.numeric(interval),
 		  PACKAGE = "R2SWF");
 	setwd(oldwd);
-	invisible(file.path(outdir, output));
+
+	output = normalizePath(output);
+	cat("SWF file created at ", output, ".\n", sep = "");
+	invisible(output);
 }
 
 ##' Convert R graphics to SWF using different graphics devices
@@ -57,6 +70,7 @@ image2swf <- function(filenames, outdir = getwd(), output = "movie.swf",
 ##' @param expr an expression to generate a sequence of images
 ##' @param outdir the output directory
 ##' @param output the name of the output swf file
+##' @param bgColor background color of the output SWF file
 ##' @param interval the time interval between animation frames
 ##' @param dev the name of the graphics device to use
 ##' (e.g. \code{'png'} or \code{'jpeg'})
@@ -78,8 +92,8 @@ image2swf <- function(filenames, outdir = getwd(), output = "movie.swf",
 ##' print(output2)
 ##'
 dev2swf <- function(expr, outdir = tempdir(), output = "movie.swf",
-					interval = 1, dev = "png", file.ext = "png",
-					img.name = "Rplot", ...)
+					bgColor = "white", interval = 1, dev = "png",
+					file.ext = "png", img.name = "Rplot", ...)
 {
     if (is.character(dev)) dev = get(dev)
 
@@ -95,7 +109,7 @@ dev2swf <- function(expr, outdir = tempdir(), output = "movie.swf",
 
     files = list.files(pattern = paste(img.name, "[0-9]*\\.", file.ext, '$', sep = ''))
 	files = file.path(tmpfolder, files)
-    output = image2swf(files, outdir, output, interval)
+    output = image2swf(files, file.path(outdir, output), bgColor, interval)
 	setwd(olddir)
 
     invisible(output)
