@@ -18,6 +18,13 @@
 
 #include "pngpriv.h"
 
+/* Added by Yixuan Qiu */
+void PNG_ABORT_WITH_R_HANDLER()
+{
+	Rf_error("Unexpected error from libpng");
+}
+
+
 #if defined(PNG_READ_SUPPORTED) || defined(PNG_WRITE_SUPPORTED)
 
 static PNG_FUNCTION(void, png_default_error,PNGARG((png_structp png_ptr,
